utils::globalVariables(c(
  "AEDECOD",
  "AESER",
  "AESEV",
  "AESTDT",
  "..prop..",
  "AETERM",
  "AGEGR",
  "AGEGRN",
  "BASE",
  "Nsubj",
  "Q1",
  "Q3",
  "SD",
  "SummStat",
  "Var1",
  "Var2",
  "animation_opts",
  "animation_slider",
  "colorRampPalette",
  "fct_explicit_na",
  "fct_infreq",
  "fct_rev",
  "fncorrmat",
  "layout",
  "pickerInput",
  "updatePickerInput",
  "updatePrettyRadioButtons",
  "value",
  "ymax",
  "ymin",
  "stats",
  "as.dist",
  "cor",
  "hclust",
  "PopuExplor",
  "AVAL",
  "AVISIT",
  "AVISITN",
  "CMDECOD",
  "CMSTDT",
  "DECODE",
  "DOMAIN",
  "END",
  "EVENTTYP",
  "Event",
  "LBDT",
  "LBDY",
  "LBSTNRHI",
  "LBSTNRLO",
  "MHCAT",
  "MHDECOD",
  "MHENDTC",
  "MHSTDTC",
  "MHTERM",
  "PARAM",
  "PARAMCD",
  "START",
  "USUBJID",
  "VISIT",
  "Visit",
  "all_of",
  "className",
  "col_exist",
  "content",
  "df",
  "df_var",
  "end",
  "error",
  "event_var",
  "f",
  "filter_code",
  "group",
  "hcl",
  "min_lbdt",
  "missing_disp",
  "not_exist",
  "not_exist_disp",
  "ord",
  "setNames",
  "sort_start",
  "str_subset",
  "start",
  "tab_en",
  "tab_st",
  "type_col",
  ".",
  "CHG",
  "ID",
  "aov",
  "block",
  "data_from",
  "dataset",
  "fct_reorder",
  "imap",
  "median",
  "na.omit",
  "prop",
  "quantile",
  "sd",
  "spread",
  "v1",
  "write.csv",
  "x",
  "js",
  "byymean",
  "max_avals",
  "ATM",
  "adsl",
  "advs",
  "adae",
  "adlbc",
  "adtte",
  "warn",
  "dy_min",
  "AEACN",
  "AEACNOTH",
  "AREL",
  "CNSR",
  "FASFL",
  "ITTFL",
  "LOWER",
  "Lower",
  "MEAN",
  "Mean (SD)",
  "Median",
  "Min | Max",
  "N",
  "PANEL",
  "Q1 | Q3",
  "SAFFL",
  "SEM",
  "STD",
  "TRTEMFL",
  "UPPER",
  "Upper",
  "Variable",
  "ae_data",
  "avals_by",
  "bds_data",
  "colour",
  "colour2",
  "corr",
  "corr_lab",
  "corr_lab_hover",
  "descr",
  "grp",
  "id_block",
  "id_desc",
  "id_rn",
  "id_stat",
  "inner_sort",
  "lab",
  "n_subgroups",
  "n_tot",
  "orig_id_rn",
  "orig_var_rn",
  "param_x",
  "param_y",
  "pt",
  "pval",
  "pval_hover",
  "sort_n",
  "v",
  "var",
  "var_rn",
  "where",
  "y",
  "type",
  "title",
  ":=",
  "DATE",
  "EVENT_TIME",
  "DATE_ST",
  "DECODE_ST",
  "DATE_EN",
  "DECODE_EN",
  "time",
  "est_ci",
  "Strata",
  "0.95LCL",
  "0.95UCL",
  "label",
  "id"
))
